***************************
FilenameParts
***************************

.. autosummary::
   :toctree:

   namefiles.NameGiver.set_parts
   namefiles.NameGiver.to_path
   namefiles.NameGiver.get_filename_validator
   namefiles.NameGiver.set_name_part
   namefiles.NameGiver.disassemble
   namefiles.NameGiver.identifier
   namefiles.NameGiver.sub_id
   namefiles.NameGiver.source_id
   namefiles.NameGiver.vargroup
   namefiles.NameGiver.context
   namefiles.NameGiver.extension

.. autoclass:: namefiles.NameGiver
